@@ -11,87 +11,6 @@ use constant SHOW_STYLE_NOT_PROCESSED => 1;
 use constant SHOW_STYLE => 0;	# insert style name in the output
 use constant SHOW_RTF_LINE_NUMBER => 0;
 
-use constant RTF_DEBUG => 0;
-
-
-
-=head1 NAME
-
-RTF::HTML::Converter - Perl extension for converting RTF into HTML
-
-=head1 DESCRIPTION
-
-Perl extension for converting RTF into HTML
-
-=head1 SYNOPSIS
-
-	use strict;
-	use RTF::HTML::Converter;
-	
-	my $object = RTF::HTML::Converter->new(
-	
-		output => \*STDOUT
-	
-	);
-
-	$object->parse_stream( \*RTF_FILE );
-	
-OR
-
-	use strict;
-	use RTF::HTML::Converter;
-	
-	my $object = RTF::HTML::Converter->new(
-	
-		output => \$string
-	
-	);
-
-	$object->parse_string( $rtf_data );
-
-=head1 METHODS
-
-=head2 new()
-
-Constructor method. Currently takes one named parameter, C<output>,
-which can either be a reference to a filehandle, or a reference to
-a string. This is where our HTML will end up.
-
-=head2 parse_stream()
-
-Read RTF in from a filehandle, and start processing it. Pass me
-a reference to a filehandle.
-
-=head2 parse_string()
-
-Read RTF in from a string, and start processing it. Pass me a string.
-
-=head1 JUST SO YOU KNOW
-
-You can mix-and-match your output and input methods - nothing to stop
-you outputting to a string when you've read from a filehandle...
-
-=head1 AUTHOR
-
-Peter Sergeant C<rtf.parser@clueball.com>, originally by Philippe Verdret
-
-=head1 COPYRIGHT
-
-Copyright 2004 B<Pete Sergeant>.
-
-This program is free software; you can redistribute it and/or modify it under
-the same terms as Perl itself.
-
-=head1 CREDITS
-
-This work was carried out under a grant generously provided by The Perl Foundation -
-give them money!
-
-
-=cut
-
-
-
 # Symbol exported by the RTF::Ouptut module:
 # %info: informations of the {\info ...}
 # %par_props: paragraph properties
@@ -116,20 +35,13 @@ my $CURRENT_LI = 0;		# current list indent
 my @LIST_STACK = ();		# stack of opened lists
 my %LI_LEVEL = ();		# li -> list level
 
-my %charmap_defaults = map({ sprintf("%02x", $_) => "&#$_;" } (0..255));
-
 my %PAR_ALIGN = qw(
 		 qc CENTER
 		 ql LEFT
 		 qr RIGHT
 		 qj LEFT
 		);
-				# here put your style mappings
 my %STYLES = ('Normal' => 'p',
-	      'Abstract' => 'Blockquote', 
-	      'PACSCode' => 'Code',
-	      #'AuthGrp' => '', 
-	      'Section' => 'H1',
 	      'heading 1' => 'H1',
 	      'heading 2' => 'H2',
 	      'heading 3' => 'H3',
@@ -375,9 +287,6 @@ use constant GEN_TAGS_WARNS => 1;
 my @element_stack = ();		
 my %open_element = ();
 sub gen_tags {			# manage a minimal context for tag outputs
-
-	debug( 'gen_tags', @_ ) if RTF_DEBUG > 5;
-
   die "bad argument number"  unless (@_ >= 2);
   my ($eve, $tag, $att)  = @_;
 
@@ -420,17 +329,19 @@ sub gen_tags {			# manage a minimal context for tag outputs
 # - method redefinition (could be the purist's solution)
 # - $Control::do_on_control{control_word} = sub {}; 
 # - when %do_on_control is exported write:
-$do_on_control{'ansi'} =	# callback redefinition
+$do_on_control{'ansi'} =	# callcack redefinition
   sub {
     # RTF: \'<hex value>
     # HTML: &#<dec value>;
-    
-    my @charmap_data = $_[SELF]->charmap_reader( $_[CONTROL] );
+    my $charset = $_[CONTROL];
+    my $charset_file = $_[SELF]->application_dir(__FILE__) . "/$charset";
+    open CHAR_MAP, "$charset_file"
+      or die "unable to open the '$charset_file': $!";
 
     my %charset = (		# general rule
-		   %charmap_defaults,
+		   map({ sprintf("%02x", $_) => "&#$_;" } (0..255)),
 				# and some specific defs
-		   map({ s/^\s+//; split /\s+/ } @charmap_data)
+		   map({ s/^\s+//; split /\s+/ } (<CHAR_MAP>))
 		  );
     *char = sub { 
       my $char_props;
@@ -444,7 +355,6 @@ $do_on_control{'ansi'} =	# callback redefinition
     } 
   };
 
-
 				# symbol processing
 				# RTF: \~
 				# named chars
@@ -454,11 +364,7 @@ $symbol{'tab'} = ' '; #'&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;';
 $symbol{'ldblquote'} = '&laquo;';
 $symbol{'rdblquote'} = '&raquo;';
 $symbol{'line'} = '<br>';
-sub symbol {	
-
-		debug( 'symbol', @_ ) if RTF_DEBUG > 5;
-
-		
+sub symbol {			
   my $char_props;
   if ($START_NEW_PARA) {	
     $char_props = $_[SELF]->force_char_props('start');
@@ -475,10 +381,6 @@ sub symbol {
 				# Text
 				# certainly do the same thing with the char() method
 sub text {			# parser callback redefinition
-
-	debug( 'text', @_ ) if RTF_DEBUG > 5;
-
-
   my $text = $_[1];
   my $char_props = '';
   if ($START_NEW_PARA) {	
@@ -497,13 +399,5 @@ sub text {			# parser callback redefinition
   }
 }
 
-sub debug {
-
-	my $function = shift;
-	
-	print STDERR "[RTF::HTML::Converter::$function]" . (join '|', @_ ) , "\n";
-
-}
-
 1;
 __END__
